==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/d2/d26db6b99d2b20799a105d991796bafc.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @JotaworksDoi/FormTheme/EmailSendList/email_to_user_row.html.twig */
class __TwigTemplate_156eb0fcc7e343c8bec1188b9c18fc90 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

/*
 * @copyright   2014 Mautic Contributors. All rights reserved
 * @author      Mautic
 *
 * @link        http://mautic.org
 *
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
?>

<div class=\"row\">
    <div class=\"col-md-6\">
        <?php echo \$view['form']->row(\$form['user_id']); ?>
    </div>
    <div class=\"col-md-6\">
        <?php echo \$view['form']->row(\$form['to_owner']); ?>
    </div>

</div>
    <?php echo \$view['form']->row(\$form['to']); ?>
    <?php echo \$view['form']->row(\$form['cc']); ?>
    <?php echo \$view['form']->row(\$form['bcc']); ?>
    <?php echo \$view['form']->rest(\$form); ?>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@JotaworksDoi/FormTheme/EmailSendList/email_to_user_row.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@JotaworksDoi/FormTheme/EmailSendList/email_to_user_row.html.twig", "/var/www/html/mauticGIT-Test/plugins/JotaworksDoiBundle/Resources/views/FormTheme/EmailSendList/email_to_user_row.html.twig");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/d2/d26db6b99d2b20799a105d991796bafc.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @JotaworksDoi/FormTheme/EmailSendList/email_to_user_row.html.twig */
class __TwigTemplate_156eb0fcc7e343c8bec1188b9c18fc90 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

/*
 * @copyright   2014 Mautic Contributors. All rights reserved
 * @author      Mautic
 *
 * @link        http://mautic.org
 *
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
?>

<div class=\"row\">
    <div class=\"col-md-6\">
        <?php echo \$view['form']->row(\$form['user_id']); ?>
    </div>
    <div class=\"col-md-6\">
        <?php echo \$view['form']->row(\$form['to_owner']); ?>
    </div>

</div>
    <?php echo \$view['form']->row(\$form['to']); ?>
    <?php echo \$view['form']->row(\$form['cc']); ?>
    <?php echo \$view['form']->row(\$form['bcc']); ?>
    <?php echo \$view['form']->rest(\$form); ?>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@JotaworksDoi/FormTheme/EmailSendList/email_to_user_row.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@JotaworksDoi/FormTheme/EmailSendList/email_to_user_row.html.twig", "/var/www/html/production-demo/plugins/JotaworksDoiBundle/Resources/views/FormTheme/EmailSendList/email_to_user_row.html.twig");
    }
}
